@@ -17,6 +17,7 @@
 #   Alessandro Amici - B-Open - https://bopen.eu
 #
 
+import json
 import os.path
 import typing as T
 
@@ -25,6 +26,21 @@ import click
 # NOTE: imports are executed inside functions so missing dependencies don't break all commands
 
 
+def handle_json(in_json):
+    """
+    Handle input json which can be a a json format string, or path to a json format file.
+    Returns a dictionary of the json contents.
+    """
+    try:
+        # Assume a json format string
+        out_json = json.loads(in_json)
+    except json.JSONDecodeError:
+        # Then a json file
+        with open(in_json, "r") as f:
+            out_json = json.load(f)
+    return out_json
+
+
 @click.group()
 def cfgrib_cli() -> None:
     pass
@@ -57,10 +73,27 @@ def selfcheck() -> None:
         "the path to JSON file"
     ),
 )
-def to_netcdf(inpaths, outpath, cdm, engine, backend_kwargs_json):
-    # type: (T.List[str], str, str, str, str) -> None
-    import json
-
+@click.option(
+    "--netcdf-kwargs-json",
+    "-n",
+    default=None,
+    help=(
+        "kwargs used xarray.to_netcdf when creating the netCDF file. "
+        "Can either be a JSON format string or the path to JSON file. "
+    ),
+)
+@click.option(
+    "--var-encoding-json",
+    "-v",
+    default=None,
+    help=(
+        "encoding options to apply to all data variables in the dataset. "
+        "Can either be a JSON format string or the path to JSON file. "
+    ),
+)
+def to_netcdf(
+    inpaths, outpath, cdm, engine, backend_kwargs_json, netcdf_kwargs_json, var_encoding_json
+):  # type: (T.List[str], str, str, str, str, str, str) -> None
     import xarray as xr
 
     import cf2cdm
@@ -73,31 +106,41 @@ def to_netcdf(inpaths, outpath, cdm, engine, backend_kwargs_json):
         outpath = os.path.splitext(inpaths[0])[0] + ".nc"
 
     if backend_kwargs_json is not None:
-        try:
-            # Assume a json format string
-            backend_kwargs = json.loads(backend_kwargs_json)
-        except json.JSONDecodeError:
-            # Then a json file
-            with open(backend_kwargs_json, "r") as f:
-                backend_kwargs = json.load(f)
+        backend_kwargs = handle_json(backend_kwargs_json)
     else:
         backend_kwargs = {}
 
     if len(inpaths) == 1:
         # avoid to depend on dask when passing only one file
         ds = xr.open_dataset(
-            inpaths[0], engine=engine, backend_kwargs=backend_kwargs,
+            inpaths[0],
+            engine=engine,
+            backend_kwargs=backend_kwargs,
         )  # type: ignore
     else:
         ds = xr.open_mfdataset(
-            inpaths, engine=engine, combine="by_coords", backend_kwargs=backend_kwargs,
+            inpaths,
+            engine=engine,
+            combine="by_coords",
+            backend_kwargs=backend_kwargs,
         )  # type: ignore
 
     if cdm:
         coord_model = getattr(cf2cdm, cdm)
         ds = cf2cdm.translate_coords(ds, coord_model=coord_model)
 
-    ds.to_netcdf(outpath)
+    if netcdf_kwargs_json is not None:
+        netcdf_kwargs = handle_json(netcdf_kwargs_json)
+    else:
+        netcdf_kwargs = {}
+
+    if var_encoding_json is not None:
+        var_encoding = handle_json(var_encoding_json)
+        netcdf_kwargs.setdefault("encoding", {})
+        for var in ds.data_vars:
+            netcdf_kwargs["encoding"].setdefault(var, var_encoding)
+
+    ds.to_netcdf(outpath, **netcdf_kwargs)
 
 
 @cfgrib_cli.command("dump")
