@@ -100,13 +100,17 @@ GRID_TYPE_MAP = {
         "latitudeOfLastGridPointInDegrees",
     ],
     "regular_gg": [
-        "Nx",
+        "N",
+        "Ni",
+        "Nj",
         "iDirectionIncrementInDegrees",
         "iScansNegatively",
+        "jScansPositively",
+        "jPointsAreConsecutive",
         "longitudeOfFirstGridPointInDegrees",
         "longitudeOfLastGridPointInDegrees",
-        "N",
-        "Ny",
+        "latitudeOfFirstGridPointInDegrees",
+        "latitudeOfLastGridPointInDegrees",
     ],
     "rotated_gg": [
         "Nx",
