@@ -30,6 +30,8 @@ import numpy as np
 
 from . import abc
 
+MISSING_VAUE_INDICATOR = np.finfo(np.float32).max
+
 eccodes_version = eccodes.codes_get_api_version()
 
 LOG = logging.getLogger(__name__)
@@ -114,6 +116,10 @@ class Message(abc.MutableField):
         codes_id = eccodes.codes_clone(message.codes_id)
         return cls(codes_id=codes_id, **kwargs)
 
+    # ensure that missing values in the values array are represented by MISSING_VAUE_INDICATOR
+    def __attrs_post_init__(self):
+        self["missingValue"] = MISSING_VAUE_INDICATOR
+
     def __del__(self) -> None:
         eccodes.codes_release(self.codes_id)
 
@@ -121,19 +127,25 @@ class Message(abc.MutableField):
         # type: (str, T.Optional[type], T.Any) -> T.Any
         """Get value of a given key as its native or specified type."""
         try:
-            values = eccodes.codes_get_array(self.codes_id, item, key_type)
+            if eccodes.codes_get_size(self.codes_id, item) > 1:
+                values = eccodes.codes_get_array(self.codes_id, item, key_type)
+            else:
+                values = [eccodes.codes_get(self.codes_id, item, key_type)]
+
             if values is None:
-                values = ["unsupported_key_type"]
+                return "unsupported_key_type"
+
+            if len(values) == 1:
+                if isinstance(values, np.ndarray):
+                    values = values.tolist()
+                return values[0]
+            return values
+
         except eccodes.KeyValueNotFoundError:
             if default is _MARKER:
                 raise KeyError(item)
             else:
                 return default
-        if len(values) == 1:
-            if isinstance(values, np.ndarray):
-                values = values.tolist()
-            return values[0]
-        return values
 
     def message_set(self, item: str, value: T.Any) -> None:
         arr = isinstance(value, (np.ndarray, T.Sequence)) and not isinstance(value, str)
